@@ -29,7 +29,7 @@ setAs("SoilProfileCollection", "data.frame", function(from) {
 ## Coercition methods: and sp utilities
 setAs("SoilProfileCollection", "SpatialPointsDataFrame", function(from) {
     cat('ony site data are extracted\n')
-    s <- SpatialPointsDataFrame(coordinates(from), data = from@site, proj4string=CRS(proj4string(from)))
+    s <- SpatialPointsDataFrame(coordinates(from), data = site(from), proj4string=CRS(proj4string(from)))
     return(s)
   }
 )
