@@ -161,11 +161,77 @@ setMethod(f='depth_units', signature='SoilProfileCollection',
 ## overloads
 ##
 
+
+## concatentation
+## TODO: check for duplicates, consider using digest
+rbind.SoilProfileCollection <- function(...) {
+	# setup some defaults
+	options(stringsAsFactors=FALSE)
+	
+	# parse dots
+	objects <- list(...)
+	names(objects) <- NULL
+	
+	# short-circuits
+	if(length(objects) == 0)
+		return(NULL)
+	if(length(objects) == 1)
+		return(objects[1])
+	
+	# combine pieces
+	# should have length of 1
+	o.idname <- unique(lapply(objects, idname))
+	o.depth.units <- unique(lapply(objects, depth_units))
+	o.hz.depths <- unique(lapply(objects, horizonDepths))
+	o.m <- unique(lapply(objects, metadata))
+	o.coords <- unique(lapply(objects, function(i) ncol(coordinates(i))))
+	o.p4s <- unique(lapply(objects, proj4string))
+	
+	# should have length > 1
+	o.h <- lapply(objects, horizons)
+	o.s <- lapply(objects, site)
+	o.d <- lapply(objects, diagnostic_hz)
+	o.sp <- lapply(objects, function(i) i@sp)
+	
+	# sanity checks:
+	if(length(o.idname) > 1)
+		stop('inconsistent ID names', call.=FALSE)
+	if(length(o.depth.units) > 1)
+		stop('inconsistent depth units', call.=FALSE)
+	if(length(o.hz.depths) > 1)
+		stop('inconsistent depth columns', call.=FALSE)
+	if(length(o.m) > 1)
+		stop('inconsistent metadata', call.=FALSE)
+	
+	# spatial data may be missing...
+	if(length(o.coords) > 1)
+		stop('inconsistent spatial data', call.=FALSE)
+	if(length(o.p4s) > 1)
+		stop('inconsistent CRS', call.=FALSE)
+	
+	# generate new SPC components
+	o.h <- do.call('rbind', o.h)
+	o.s <- do.call('rbind', o.s)
+	o.d <- do.call('rbind', o.d)
+	
+	# spatial points require some more effort when spatial data are missing
+	o.1.sp <- objects[[1]]@sp
+	if(ncol(coordinates(o.1.sp)) == 1) # missing spatial data
+		o.sp <- o.1.sp # copy the first filler
+	else # not missing spatial data
+		o.sp <- do.call('rbind', o.sp) # rbind properly
+	
+	# make SPC and return
+	res <- SoilProfileCollection(idcol=o.idname[[1]], depthcols=o.hz.depths[[1]], metadata=o.m[[1]], horizons=o.h, site=o.s, sp=o.sp, diagnostic=o.d)
+	
+	return(res)
+	}
+
+
 ## column names
-## TODO: should this return a named list?
 setMethod("names", "SoilProfileCollection",
   function(x) {
-  res <- c(names(horizons(x)), names(site(x)))
+  res <- list(horizons=names(horizons(x)), site=names(site(x)))
   return(res)
   }
 )
@@ -208,6 +274,33 @@ setMethod(f='nrow', signature='SoilProfileCollection',
 )
 
 
+# overload unique() via digest eval of unique profiles
+# currently only works with horizon-level attributes
+setMethod(f='unique', signature='SoilProfileCollection',
+definition=function(x, vars){
+  if(require(digest)) {
+	md5 <- profileApply(x, function(i) digest(unlist(horizons(i)[, vars])))
+
+	# get unique hashes
+	u.md5 <- unique(md5)
+
+	# list profile idx by hash:
+	profiles.by.hash <- sapply(u.md5, function(i) which(md5 == i), simplify=FALSE)
+
+	# get an index of the first copy of each profile
+	u.profiles <- sapply(profiles.by.hash, function(i) i[1])
+	
+	# return an index of unique profiles
+	# down-grade to un-named vector of indices
+	return(as.vector(u.profiles))
+	}
+  else
+		stop('This function requres the `digest` package.', call.=FALSE)
+	
+  }
+)
+
+
 
 
 ## standard column access: search horizons, then site
@@ -246,7 +339,7 @@ setReplaceMethod("$", "SoilProfileCollection",
   function(x, name, value) {
   	# extract hz and site data
   	h <- horizons(x)
-	s <- site(x)
+		s <- site(x)
 
     # working with horizon data
     if (name %in% names(h)) {
@@ -370,12 +463,17 @@ setMethod("[", "SoilProfileCollection",
       # combine with coordinates
       cat('result is a SpatialPointsDataFrame object\n')
       # note that we are filtering based on 'i' - an index of selected profiles
-
+			
+      # since the order of our slices and coordinates are the same
+      # it is safe to use 'match.ID=FALSE'
+      # this gets around a potential problem when dimnames(x)[[1]] aren't consecutive 
+      # values-- often the case when subsetting has been performed
+      
       # if site data, join hz+site
       if(nrow(s) > 0)
-      	return(SpatialPointsDataFrame(coordinates(x)[i, ], data=join(h, s, by=idname(x))))
+      	return(SpatialPointsDataFrame(coordinates(x)[i, ], data=join(h, s, by=idname(x)), match.ID=FALSE))
       else # no site data
-      	return(SpatialPointsDataFrame(coordinates(x)[i, ], data=h))	
+      	return(SpatialPointsDataFrame(coordinates(x)[i, ], data=h, match.ID=FALSE))	
     }
 
     # in this case there may be missing coordinates, or we have more than 1 slice of hz data
