@@ -1,7 +1,7 @@
 
 ## TODO: iterate over profile IDs instead of groups
 # TODO: document this
-.make.segments <- function(df)
+make.segments <- function(df)
 	{
 	require(lattice)
 	
