@@ -59,8 +59,8 @@ plotSPC <- function(x, color='soil_color', width=0.2, name='name', cex.names=0.5
   # init plotting region, unless we are appending to an existing plot
   # note that we are using some fudge-factors to get the plotting region just right
   if(!add) {
-    par(mar=c(0.5,1,0,1))
-	  plot(0, 0, type='n', xlim=c(1-(extra_x_space/20), n+extra_x_space), ylim=c(max(depth_axis_intervals), -4), axes=FALSE)
+    # par(mar=c(0.5,1,0,1)) # is it wise to adjust the plotting area?
+	  plot(0, 0, type='n', xlim=c(1-(extra_x_space/20), n+extra_x_space), ylim=c(max(depth_axis_intervals), -4), axes=FALSE, xlab='', ylab='')
 	}
   
   
